#!/bin/sh
#-----------------------------------------------------------#
# シェル名: common.sh
#-----------------------------------------------------------#
# 処理概要: 共通に使用する変数、関数を記述
#-----------------------------------------------------------#
# 2008/12/1 SoSO
#-----------------------------------------------------------#

#-----------------------------------------------------------#
# 変数
#-----------------------------------------------------------#
# パス
#_MNT_DIR_="/media/LinuxMania_Customize_Disc"
_MNT_DIR_="$(pwd)/../.."
_SCRPT_DATA_DIR_="$_MNT_DIR_/.data"
_SCRPT_COMMON_DIR_="$_SCRPT_DATA_DIR_/common"

# ログ
_LM_DIR_="/usr/share/linuxmania"
_LOG_DIR_="$_LM_DIR_/log"
_CUS_LOG_="$_LOG_DIR_/lm_customize.log"  # カスタマイズの実行.sh のログ
_ADD_LOG_="$_LOG_DIR_/lm_additional.log"  # 追加アプリケーションのインストール.sh のログ
_DRV_LOG_="$_LOG_DIR_/lm_nvidia.log"  # nvidiaドライバのインストール.sh のログ

# 作業領域
_LM_TEMP_DIR_="/tmp/lm"

#-----------------------------------------------------------#
# 準備
#-----------------------------------------------------------#
# ディレクトリ作成
mkdir -p "$_LM_DIR_"
mkdir -p "$_LOG_DIR_"
mkdir -p "$_LM_TEMP_DIR_"

#-----------------------------------------------------------#
# 関数
#-----------------------------------------------------------#
#-----------------------------------------------------------#
# メソッド名: ReplaceFile
# 処理概要　: ファイルを Perl 正規表現で書き換える
# 引数 : regex : perl の正規表現 (例. 's/AAA/BBB/g')
#        filename : 書き換えたいファイル (例. /tmp/test.txt)
# 返り値: なし
#-----------------------------------------------------------#
function ReplaceFile() {
	regex=$1
	filename=$2
	$_SCRPT_COMMON_DIR_/renew.sh "$1" "$2"
}

#-----------------------------------------------------------#
# メソッド名: LogWrite
# 処理概要　: ログ書き出し
# 引数　　　: ファイル名、出力内容(4つまで)
# 返り値　　: なし
#-----------------------------------------------------------#
function LogWrite() {
	echo "$2 $3 $4 $5" >> "$1"
}

#-----------------------------------------------------------#
# メソッド名: LogStart
# 処理　: ログ書き込み開始
# 引数　: ログファイル
# 返り値: なし
#-----------------------------------------------------------#
function LogStart() {
	LogWrite $1 "--------------------------------------------------------------"	
	LogWrite $1 "[LOG START] $0: $(date +'%Y/%m/%d %H:%M')"
	LogWrite $1 ""
}

#-----------------------------------------------------------#
# メソッド名: LogEnd
# 処理　: ログ書き込み終了
# 引数　: ログファイル
# 返り値: なし
#-----------------------------------------------------------#
function LogEnd() {
	LogWrite $1 ""
	LogWrite $1 "[LOG END] $0: $(date +'%Y/%m/%d %H:%M')"
	LogWrite $1 ""
}




